DECLARE
    vl_MsgError VARCHAR2(255);
    eFalloMod EXCEPTION;
BEGIN

    -- Table structure for table REGION
    DECLARE cnt1 NUMBER;
    BEGIN
        SELECT count(*) INTO cnt1 FROM all_tables WHERE table_name = 'REGION';
        IF cnt1 = 0 THEN
            EXECUTE IMMEDIATE 'CREATE TABLE REGION
                            ( REGION_ID number(2) NOT NULL PRIMARY KEY,
                              REGION_NOMBRE varchar2(50) NULL
                            )';
        ELSE
            EXECUTE IMMEDIATE 'DELETE COMUNA';
            EXECUTE IMMEDIATE 'DELETE PROVINCIA';
            EXECUTE IMMEDIATE 'DELETE REGION';
        END IF;
    EXCEPTION
        WHEN OTHERS THEN
            vl_MsgError := 'Error en etapa 1 - estructura tabla REGION';
            RAISE eFalloMod;
    END;

    -- Table structure for table PROVINCIA
    DECLARE cnt2 NUMBER;
    BEGIN
        SELECT count(*) INTO cnt2 FROM all_tables WHERE table_name = 'PROVINCIA';
        IF cnt2 = 0 THEN
            EXECUTE IMMEDIATE 'CREATE TABLE PROVINCIA
                         (
                           PROVINCIA_ID number(3) NOT NULL PRIMARY KEY,
                           PROVINCIA_NOMBRE varchar2(23) NULL,
                           PROVINCIA_REGION_ID number(2) NULL,
                           CONSTRAINT provincia_ibfk_1
                               FOREIGN KEY (PROVINCIA_REGION_ID)
                               REFERENCES REGION(REGION_ID)
                         )';
        ELSE
            EXECUTE IMMEDIATE 'DELETE COMUNA';
            EXECUTE IMMEDIATE 'DELETE PROVINCIA';
            EXECUTE IMMEDIATE 'DELETE REGION';
        END IF;
    EXCEPTION
        WHEN OTHERS THEN
            vl_MsgError := 'Error en etapa 2 - estructura tabla PROVINCIA';
            RAISE eFalloMod;
    END;

    -- Table structure for table COMUNA
    DECLARE cnt3 NUMBER;
    BEGIN
        SELECT count(*) INTO cnt3 FROM all_tables WHERE table_name = 'COMUNA';
        IF cnt3 = 0 THEN
            EXECUTE IMMEDIATE 'CREATE TABLE COMUNA
                        (
                          COMUNA_ID number(5) NOT NULL PRIMARY KEY,
                          COMUNA_NOMBRE varchar2(20) NULL,
                          COMUNA_PROVINCIA_ID number(3) NULL,
                          CONSTRAINT comuna_ibfk_1
                              FOREIGN KEY (COMUNA_PROVINCIA_ID)
                              REFERENCES PROVINCIA(PROVINCIA_ID)
                        )';
        ELSE
            EXECUTE IMMEDIATE 'DELETE COMUNA';
            EXECUTE IMMEDIATE 'DELETE PROVINCIA';
            EXECUTE IMMEDIATE 'DELETE REGION';
        END IF;
    EXCEPTION
        WHEN OTHERS THEN
            vl_MsgError := 'Error en etapa 3 - estructura tabla COMUNA';
            RAISE eFalloMod;
    END;

    ----------------------------------------------------------------------
    -- Dumping data for table REGION
    BEGIN
        INSERT ALL
            INTO REGION (REGION_ID, REGION_NOMBRE) VALUES (1, 'Tarapacá')
            INTO REGION (REGION_ID, REGION_NOMBRE) VALUES (2, 'Antofagasta')
            INTO REGION (REGION_ID, REGION_NOMBRE) VALUES (3, 'Atacama')
            INTO REGION (REGION_ID, REGION_NOMBRE) VALUES (4, 'Coquimbo')
            INTO REGION (REGION_ID, REGION_NOMBRE) VALUES (5, 'Valparaíso')
            INTO REGION (REGION_ID, REGION_NOMBRE) VALUES (6, 'Región del Libertador Gral. Bernardo O’Higgins')
            INTO REGION (REGION_ID, REGION_NOMBRE) VALUES (7, 'Región del Maule')
            INTO REGION (REGION_ID, REGION_NOMBRE) VALUES (8, 'Región del Biobío')
            INTO REGION (REGION_ID, REGION_NOMBRE) VALUES (9, 'Región de la Araucanía')
            INTO REGION (REGION_ID, REGION_NOMBRE) VALUES (10, 'Región de Los Lagos')
            INTO REGION (REGION_ID, REGION_NOMBRE) VALUES (11, 'Región Aisén del Gral. Carlos Ibáñez del Campo')
            INTO REGION (REGION_ID, REGION_NOMBRE) VALUES (12, 'Región de Magallanes y de la Antártica Chilena')
            INTO REGION (REGION_ID, REGION_NOMBRE) VALUES (13, 'Región Metropolitana de Santiago')
            INTO REGION (REGION_ID, REGION_NOMBRE) VALUES (14, 'Región de Los Ríos')
            INTO REGION (REGION_ID, REGION_NOMBRE) VALUES (15, 'Arica y Parinacota')
            SELECT 1 FROM DUAL;

        IF SQL%NOTFOUND THEN
            vl_MsgError := 'Error dumping data to table REGION';
            RAISE eFalloMod;
        END IF;
    EXCEPTION
        WHEN OTHERS THEN
            RAISE;
    END;

    ----------------------------------------------------------------------
    -- Dumping data for table PROVINCIA
    BEGIN
        INSERT ALL
            INTO PROVINCIA (PROVINCIA_ID, PROVINCIA_NOMBRE, PROVINCIA_REGION_ID) VALUES (11, 'Iquique', 1)
            INTO PROVINCIA (PROVINCIA_ID, PROVINCIA_NOMBRE, PROVINCIA_REGION_ID) VALUES (14, 'Tamarugal', 1)
            INTO PROVINCIA (PROVINCIA_ID, PROVINCIA_NOMBRE, PROVINCIA_REGION_ID) VALUES (21, 'Antofagasta', 2)
            INTO PROVINCIA (PROVINCIA_ID, PROVINCIA_NOMBRE, PROVINCIA_REGION_ID) VALUES (22, 'El Loa', 2)
            INTO PROVINCIA (PROVINCIA_ID, PROVINCIA_NOMBRE, PROVINCIA_REGION_ID) VALUES (23, 'Tocopilla', 2)
            INTO PROVINCIA (PROVINCIA_ID, PROVINCIA_NOMBRE, PROVINCIA_REGION_ID) VALUES (31, 'Copiapó', 3)
            INTO PROVINCIA (PROVINCIA_ID, PROVINCIA_NOMBRE, PROVINCIA_REGION_ID) VALUES (32, 'Chañaral', 3)
            INTO PROVINCIA (PROVINCIA_ID, PROVINCIA_NOMBRE, PROVINCIA_REGION_ID) VALUES (33, 'Huasco', 3)
            INTO PROVINCIA (PROVINCIA_ID, PROVINCIA_NOMBRE, PROVINCIA_REGION_ID) VALUES (41, 'Elqui', 4)
            INTO PROVINCIA (PROVINCIA_ID, PROVINCIA_NOMBRE, PROVINCIA_REGION_ID) VALUES (42, 'Choapa', 4)
            INTO PROVINCIA (PROVINCIA_ID, PROVINCIA_NOMBRE, PROVINCIA_REGION_ID) VALUES (43, 'Limarí', 4)
            INTO PROVINCIA (PROVINCIA_ID, PROVINCIA_NOMBRE, PROVINCIA_REGION_ID) VALUES (51, 'Valparaíso', 5)
            INTO PROVINCIA (PROVINCIA_ID, PROVINCIA_NOMBRE, PROVINCIA_REGION_ID) VALUES (52, 'Isla de Pascua', 5)
            INTO PROVINCIA (PROVINCIA_ID, PROVINCIA_NOMBRE, PROVINCIA_REGION_ID) VALUES (53, 'Los Andes', 5)
            INTO PROVINCIA (PROVINCIA_ID, PROVINCIA_NOMBRE, PROVINCIA_REGION_ID) VALUES (54, 'Petorca', 5)
            INTO PROVINCIA (PROVINCIA_ID, PROVINCIA_NOMBRE, PROVINCIA_REGION_ID) VALUES (55, 'Quillota', 5)
            INTO PROVINCIA (PROVINCIA_ID, PROVINCIA_NOMBRE, PROVINCIA_REGION_ID) VALUES (56, 'San Antonio', 5)
            INTO PROVINCIA (PROVINCIA_ID, PROVINCIA_NOMBRE, PROVINCIA_REGION_ID) VALUES (57, 'San Felipe de Aconcagua', 5)
            INTO PROVINCIA (PROVINCIA_ID, PROVINCIA_NOMBRE, PROVINCIA_REGION_ID) VALUES (58, 'Marga Marga', 5)
            INTO PROVINCIA (PROVINCIA_ID, PROVINCIA_NOMBRE, PROVINCIA_REGION_ID) VALUES (61, 'Cachapoal', 6)
            INTO PROVINCIA (PROVINCIA_ID, PROVINCIA_NOMBRE, PROVINCIA_REGION_ID) VALUES (62, 'Cardenal Caro', 6)
            INTO PROVINCIA (PROVINCIA_ID, PROVINCIA_NOMBRE, PROVINCIA_REGION_ID) VALUES (63, 'Colchagua', 6)
            INTO PROVINCIA (PROVINCIA_ID, PROVINCIA_NOMBRE, PROVINCIA_REGION_ID) VALUES (71, 'Talca', 7)
            INTO PROVINCIA (PROVINCIA_ID, PROVINCIA_NOMBRE, PROVINCIA_REGION_ID) VALUES (72, 'Cauquenes', 7)
            INTO PROVINCIA (PROVINCIA_ID, PROVINCIA_NOMBRE, PROVINCIA_REGION_ID) VALUES (73, 'Curicó', 7)
            INTO PROVINCIA (PROVINCIA_ID, PROVINCIA_NOMBRE, PROVINCIA_REGION_ID) VALUES (74, 'Linares', 7)
            INTO PROVINCIA (PROVINCIA_ID, PROVINCIA_NOMBRE, PROVINCIA_REGION_ID) VALUES (81, 'Concepción', 8)
            INTO PROVINCIA (PROVINCIA_ID, PROVINCIA_NOMBRE, PROVINCIA_REGION_ID) VALUES (82, 'Arauco', 8)
            INTO PROVINCIA (PROVINCIA_ID, PROVINCIA_NOMBRE, PROVINCIA_REGION_ID) VALUES (83, 'Biobío', 8)
            INTO PROVINCIA (PROVINCIA_ID, PROVINCIA_NOMBRE, PROVINCIA_REGION_ID) VALUES (84, 'Ñuble', 8)
            INTO PROVINCIA (PROVINCIA_ID, PROVINCIA_NOMBRE, PROVINCIA_REGION_ID) VALUES (91, 'Cautín', 9)
            INTO PROVINCIA (PROVINCIA_ID, PROVINCIA_NOMBRE, PROVINCIA_REGION_ID) VALUES (92, 'Malleco', 9)
            INTO PROVINCIA (PROVINCIA_ID, PROVINCIA_NOMBRE, PROVINCIA_REGION_ID) VALUES (101, 'Llanquihue', 10)
            INTO PROVINCIA (PROVINCIA_ID, PROVINCIA_NOMBRE, PROVINCIA_REGION_ID) VALUES (102, 'Chiloé', 10)
            INTO PROVINCIA (PROVINCIA_ID, PROVINCIA_NOMBRE, PROVINCIA_REGION_ID) VALUES (103, 'Osorno', 10)
            INTO PROVINCIA (PROVINCIA_ID, PROVINCIA_NOMBRE, PROVINCIA_REGION_ID) VALUES (104, 'Palena', 10)
            INTO PROVINCIA (PROVINCIA_ID, PROVINCIA_NOMBRE, PROVINCIA_REGION_ID) VALUES (111, 'Coihaique', 11)
            INTO PROVINCIA (PROVINCIA_ID, PROVINCIA_NOMBRE, PROVINCIA_REGION_ID) VALUES (112, 'Aisén', 11)
            INTO PROVINCIA (PROVINCIA_ID, PROVINCIA_NOMBRE, PROVINCIA_REGION_ID) VALUES (113, 'Capitán Prat', 11)
            INTO PROVINCIA (PROVINCIA_ID, PROVINCIA_NOMBRE, PROVINCIA_REGION_ID) VALUES (114, 'General Carrera', 11)
            INTO PROVINCIA (PROVINCIA_ID, PROVINCIA_NOMBRE, PROVINCIA_REGION_ID) VALUES (121, 'Magallanes', 12)
            INTO PROVINCIA (PROVINCIA_ID, PROVINCIA_NOMBRE, PROVINCIA_REGION_ID) VALUES (122, 'Antártica Chilena', 12)
            INTO PROVINCIA (PROVINCIA_ID, PROVINCIA_NOMBRE, PROVINCIA_REGION_ID) VALUES (123, 'Tierra del Fuego', 12)
            INTO PROVINCIA (PROVINCIA_ID, PROVINCIA_NOMBRE, PROVINCIA_REGION_ID) VALUES (124, 'Última Esperanza', 12)
            INTO PROVINCIA (PROVINCIA_ID, PROVINCIA_NOMBRE, PROVINCIA_REGION_ID) VALUES (131, 'Santiago', 13)
            INTO PROVINCIA (PROVINCIA_ID, PROVINCIA_NOMBRE, PROVINCIA_REGION_ID) VALUES (132, 'Cordillera', 13)
            INTO PROVINCIA (PROVINCIA_ID, PROVINCIA_NOMBRE, PROVINCIA_REGION_ID) VALUES (133, 'Chacabuco', 13)
            INTO PROVINCIA (PROVINCIA_ID, PROVINCIA_NOMBRE, PROVINCIA_REGION_ID) VALUES (134, 'Maipo', 13)
            INTO PROVINCIA (PROVINCIA_ID, PROVINCIA_NOMBRE, PROVINCIA_REGION_ID) VALUES (135, 'Melipilla', 13)
            INTO PROVINCIA (PROVINCIA_ID, PROVINCIA_NOMBRE, PROVINCIA_REGION_ID) VALUES (136, 'Talagante', 13)
            INTO PROVINCIA (PROVINCIA_ID, PROVINCIA_NOMBRE, PROVINCIA_REGION_ID) VALUES (141, 'Valdivia', 14)
            INTO PROVINCIA (PROVINCIA_ID, PROVINCIA_NOMBRE, PROVINCIA_REGION_ID) VALUES (142, 'Ranco', 14)
            INTO PROVINCIA (PROVINCIA_ID, PROVINCIA_NOMBRE, PROVINCIA_REGION_ID) VALUES (151, 'Arica', 15)
            INTO PROVINCIA (PROVINCIA_ID, PROVINCIA_NOMBRE, PROVINCIA_REGION_ID) VALUES (152, 'Parinacota', 15)
            SELECT 1 FROM DUAL;

        IF SQL%NOTFOUND THEN
            vl_MsgError := 'Error dumping data to table PROVINCIA';
            RAISE eFalloMod;
        END IF;

    EXCEPTION
        WHEN OTHERS THEN
            RAISE;
    END;

    ----------------------------------------------------------------------
    -- Dumping data for table COMUNA
    BEGIN
        INSERT ALL
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (1101, 'Iquique', 11)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (1107, 'Alto Hospicio', 11)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (1401, 'Pozo Almonte', 14)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (1402, 'Camiña', 14)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (1403, 'Colchane', 14)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (1404, 'Huara', 14)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (1405, 'Pica', 14)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (2101, 'Antofagasta', 21)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (2102, 'Mejillones', 21)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (2103, 'Sierra Gorda', 21)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (2104, 'Taltal', 21)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (2201, 'Calama', 22)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (2202, 'Ollagüe', 22)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (2203, 'San Pedro de Atacama', 22)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (2301, 'Tocopilla', 23)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (2302, 'María Elena', 23)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (3101, 'Copiapó', 31)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (3102, 'Caldera', 31)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (3103, 'Tierra Amarilla', 31)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (3201, 'Chañaral', 32)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (3202, 'Diego de Almagro', 32)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (3301, 'Vallenar', 33)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (3302, 'Alto del Carmen', 33)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (3303, 'Freirina', 33)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (3304, 'Huasco', 33)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (4101, 'La Serena', 41)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (4102, 'Coquimbo', 41)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (4103, 'Andacollo', 41)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (4104, 'La Higuera', 41)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (4105, 'Paihuano', 41)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (4106, 'Vicuña', 41)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (4201, 'Illapel', 42)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (4202, 'Canela', 42)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (4203, 'Los Vilos', 42)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (4204, 'Salamanca', 42)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (4301, 'Ovalle', 43)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (4302, 'Combarbalá', 43)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (4303, 'Monte Patria', 43)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (4304, 'Punitaqui', 43)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (4305, 'Río Hurtado', 43)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (5101, 'Valparaíso', 51)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (5102, 'Casablanca', 51)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (5103, 'Concón', 51)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (5104, 'Juan Fernández', 51)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (5105, 'Puchuncaví', 51)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (5107, 'Quintero', 51)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (5109, 'Viña del Mar', 51)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (5201, 'Isla de Pascua', 52)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (5301, 'Los Andes', 53)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (5302, 'Calle Larga', 53)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (5303, 'Rinconada', 53)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (5304, 'San Esteban', 53)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (5401, 'La Ligua', 54)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (5402, 'Cabildo', 54)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (5403, 'Papudo', 54)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (5404, 'Petorca', 54)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (5405, 'Zapallar', 54)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (5501, 'Quillota', 55)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (5502, 'La Calera', 55)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (5503, 'Hijuelas', 55)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (5504, 'La Cruz', 55)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (5506, 'Nogales', 55)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (5601, 'San Antonio', 56)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (5602, 'Algarrobo', 56)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (5603, 'Cartagena', 56)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (5604, 'El Quisco', 56)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (5605, 'El Tabo', 56)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (5606, 'Santo Domingo', 56)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (5701, 'San Felipe', 57)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (5702, 'Catemu', 57)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (5703, 'Llay Llay', 57)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (5704, 'Panquehue', 57)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (5705, 'Putaendo', 57)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (5706, 'Santa María', 57)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (5801, 'Quilpué', 58)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (5802, 'Limache', 58)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (5803, 'Olmué', 58)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (5804, 'Villa Alemana', 58)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (6101, 'Rancagua', 61)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (6102, 'Codegua', 61)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (6103, 'Coinco', 61)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (6104, 'Coltauco', 61)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (6105, 'Doñihue', 61)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (6106, 'Graneros', 61)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (6107, 'Las Cabras', 61)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (6108, 'Machalí', 61)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (6109, 'Malloa', 61)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (6110, 'Mostazal', 61)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (6111, 'Olivar', 61)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (6112, 'Peumo', 61)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (6113, 'Pichidegua', 61)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (6114, 'Quinta de Tilcoco', 61)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (6115, 'Rengo', 61)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (6116, 'Requínoa', 61)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (6117, 'San Vicente', 61)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (6201, 'Pichilemu', 62)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (6202, 'La Estrella', 62)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (6203, 'Litueche', 62)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (6204, 'Marchihue', 62)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (6205, 'Navidad', 62)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (6206, 'Paredones', 62)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (6301, 'San Fernando', 63)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (6302, 'Chépica', 63)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (6303, 'Chimbarongo', 63)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (6304, 'Lolol', 63)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (6305, 'Nancagua', 63)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (6306, 'Palmilla', 63)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (6307, 'Peralillo', 63)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (6308, 'Placilla', 63)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (6309, 'Pumanque', 63)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (6310, 'Santa Cruz', 63)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (7101, 'Talca', 71)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (7102, 'Constitución', 71)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (7103, 'Curepto', 71)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (7104, 'Empedrado', 71)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (7105, 'Maule', 71)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (7106, 'Pelarco', 71)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (7107, 'Pencahue', 71)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (7108, 'Río Claro', 71)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (7109, 'San Clemente', 71)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (7110, 'San Rafael', 71)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (7201, 'Cauquenes', 72)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (7202, 'Chanco', 72)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (7203, 'Pelluhue', 72)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (7301, 'Curicó', 73)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (7302, 'Hualañé', 73)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (7303, 'Licantén', 73)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (7304, 'Molina', 73)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (7305, 'Rauco', 73)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (7306, 'Romeral', 73)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (7307, 'Sagrada Familia', 73)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (7308, 'Teno', 73)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (7309, 'Vichuquén', 73)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (7401, 'Linares', 74)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (7402, 'Colbún', 74)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (7403, 'Longaví', 74)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (7404, 'Parral', 74)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (7405, 'Retiro', 74)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (7406, 'San Javier', 74)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (7407, 'Villa Alegre', 74)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (7408, 'Yerbas Buenas', 74)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (8101, 'Concepción', 81)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (8102, 'Coronel', 81)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (8103, 'Chiguayante', 81)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (8104, 'Florida', 81)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (8105, 'Hualqui', 81)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (8106, 'Lota', 81)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (8107, 'Penco', 81)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (8108, 'San Pedro de la Paz', 81)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (8109, 'Santa Juana', 81)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (8110, 'Talcahuano', 81)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (8111, 'Tomé', 81)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (8112, 'Hualpén', 81)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (8201, 'Lebu', 82)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (8202, 'Arauco', 82)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (8203, 'Cañete', 82)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (8204, 'Contulmo', 82)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (8205, 'Curanilahue', 82)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (8206, 'Los Álamos', 82)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (8207, 'Tirúa', 82)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (8301, 'Los Ángeles', 83)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (8302, 'Antuco', 83)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (8303, 'Cabrero', 83)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (8304, 'Laja', 83)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (8305, 'Mulchén', 83)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (8306, 'Nacimiento', 83)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (8307, 'Negrete', 83)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (8308, 'Quilaco', 83)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (8309, 'Quilleco', 83)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (8310, 'San Rosendo', 83)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (8311, 'Santa Bárbara', 83)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (8312, 'Tucapel', 83)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (8313, 'Yumbel', 83)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (8314, 'Alto Biobío', 83)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (8401, 'Chillán', 84)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (8402, 'Bulnes', 84)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (8403, 'Cobquecura', 84)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (8404, 'Coelemu', 84)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (8405, 'Coihueco', 84)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (8406, 'Chillán Viejo', 84)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (8407, 'El Carmen', 84)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (8408, 'Ninhue', 84)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (8409, 'Ñiquén', 84)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (8410, 'Pemuco', 84)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (8411, 'Pinto', 84)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (8412, 'Portezuelo', 84)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (8413, 'Quillón', 84)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (8414, 'Quirihue', 84)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (8415, 'Ránquil', 84)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (8416, 'San Carlos', 84)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (8417, 'San Fabián', 84)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (8418, 'San Ignacio', 84)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (8419, 'San Nicolás', 84)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (8420, 'Treguaco', 84)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (8421, 'Yungay', 84)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (9101, 'Temuco', 91)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (9102, 'Carahue', 91)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (9103, 'Cunco', 91)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (9104, 'Curarrehue', 91)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (9105, 'Freire', 91)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (9106, 'Galvarino', 91)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (9107, 'Gorbea', 91)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (9108, 'Lautaro', 91)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (9109, 'Loncoche', 91)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (9110, 'Melipeuco', 91)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (9111, 'Nueva Imperial', 91)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (9112, 'Padre las Casas', 91)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (9113, 'Perquenco', 91)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (9114, 'Pitrufquén', 91)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (9115, 'Pucón', 91)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (9116, 'Saavedra', 91)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (9117, 'Teodoro Schmidt', 91)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (9118, 'Toltén', 91)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (9119, 'Vilcún', 91)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (9120, 'Villarrica', 91)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (9121, 'Cholchol', 91)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (9201, 'Angol', 92)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (9202, 'Collipulli', 92)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (9203, 'Curacautín', 92)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (9204, 'Ercilla', 92)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (9205, 'Lonquimay', 92)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (9206, 'Los Sauces', 92)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (9207, 'Lumaco', 92)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (9208, 'Purén', 92)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (9209, 'Renaico', 92)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (9210, 'Traiguén', 92)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (9211, 'Victoria', 92)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (10101, 'Puerto Montt', 101)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (10102, 'Calbuco', 101)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (10103, 'Cochamó', 101)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (10104, 'Fresia', 101)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (10105, 'Frutillar', 101)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (10106, 'Los Muermos', 101)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (10107, 'Llanquihue', 101)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (10108, 'Maullín', 101)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (10109, 'Puerto Varas', 101)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (10201, 'Castro', 102)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (10202, 'Ancud', 102)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (10203, 'Chonchi', 102)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (10204, 'Curaco de Vélez', 102)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (10205, 'Dalcahue', 102)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (10206, 'Puqueldón', 102)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (10207, 'Queilén', 102)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (10208, 'Quellón', 102)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (10209, 'Quemchi', 102)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (10210, 'Quinchao', 102)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (10301, 'Osorno', 103)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (10302, 'Puerto Octay', 103)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (10303, 'Purranque', 103)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (10304, 'Puyehue', 103)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (10305, 'Río Negro', 103)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (10306, 'San Juan de la Costa', 103)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (10307, 'San Pablo', 103)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (10401, 'Chaitén', 104)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (10402, 'Futaleufú', 104)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (10403, 'Hualaihué', 104)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (10404, 'Palena', 104)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (11101, 'Coyhaique', 111)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (11102, 'Lago Verde', 111)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (11201, 'Aysén', 112)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (11202, 'Cisnes', 112)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (11203, 'Guaitecas', 112)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (11301, 'Cochrane', 113)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (11302, 'O''Higgins', 113)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (11303, 'Tortel', 113)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (11401, 'Chile Chico', 114)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (11402, 'Río Ibáñez', 114)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (12101, 'Punta Arenas', 121)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (12102, 'Laguna Blanca', 121)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (12103, 'Río Verde', 121)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (12104, 'San Gregorio', 121)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (12201, 'Cabo de Hornos', 122)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (12202, 'Antártica', 122)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (12301, 'Porvenir', 123)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (12302, 'Primavera', 123)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (12303, 'Timaukel', 123)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (12401, 'Natales', 124)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (12402, 'Torres del Paine', 124)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (13101, 'Santiago', 131)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (13102, 'Cerrillos', 131)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (13103, 'Cerro Navia', 131)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (13104, 'Conchalí', 131)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (13105, 'El Bosque', 131)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (13106, 'Estación Central', 131)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (13107, 'Huechuraba', 131)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (13108, 'Independencia', 131)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (13109, 'La Cisterna', 131)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (13110, 'La Florida', 131)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (13111, 'La Granja', 131)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (13112, 'La Pintana', 131)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (13113, 'La Reina', 131)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (13114, 'Las Condes', 131)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (13115, 'Lo Barnechea', 131)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (13116, 'Lo Espejo', 131)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (13117, 'Lo Prado', 131)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (13118, 'Macul', 131)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (13119, 'Maipú', 131)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (13120, 'Ñuñoa', 131)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (13121, 'Pedro Aguirre Cerda', 131)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (13122, 'Peñalolén', 131)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (13123, 'Providencia', 131)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (13124, 'Pudahuel', 131)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (13125, 'Quilicura', 131)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (13126, 'Quinta Normal', 131)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (13127, 'Recoleta', 131)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (13128, 'Renca', 131)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (13129, 'San Joaquín', 131)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (13130, 'San Miguel', 131)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (13131, 'San Ramón', 131)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (13132, 'Vitacura', 131)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (13201, 'Puente Alto', 132)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (13202, 'Pirque', 132)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (13203, 'San José de Maipo', 132)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (13301, 'Colina', 133)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (13302, 'Lampa', 133)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (13303, 'Tiltil', 133)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (13401, 'San Bernardo', 134)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (13402, 'Buin', 134)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (13403, 'Calera de Tango', 134)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (13404, 'Paine', 134)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (13501, 'Melipilla', 135)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (13502, 'Alhué', 135)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (13503, 'Curacaví', 135)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (13504, 'María Pinto', 135)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (13505, 'San Pedro', 135)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (13601, 'Talagante', 136)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (13602, 'El Monte', 136)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (13603, 'Isla de Maipo', 136)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (13604, 'Padre Hurtado', 136)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (13605, 'Peñaflor', 136)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (14101, 'Valdivia', 141)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (14102, 'Corral', 141)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (14103, 'Lanco', 141)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (14104, 'Los Lagos', 141)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (14105, 'Máfil', 141)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (14106, 'Mariquina', 141)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (14107, 'Paillaco', 141)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (14108, 'Panguipulli', 141)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (14201, 'La Unión', 142)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (14202, 'Futrono', 142)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (14203, 'Lago Ranco', 142)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (14204, 'Río Bueno', 142)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (15101, 'Arica', 151)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (15102, 'Camarones', 151)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (15201, 'Putre', 152)
            INTO COMUNA (COMUNA_ID, COMUNA_NOMBRE, COMUNA_PROVINCIA_ID) VALUES (15202, 'General Lagos', 152)
            SELECT 1 FROM DUAL;

        IF SQL%NOTFOUND THEN
            vl_MsgError := 'Error dumping data to table COMUNA';
            RAISE eFalloMod;
        END IF;

    EXCEPTION
        WHEN OTHERS THEN
            ROLLBACK;
            RAISE;
    END;

END;

-- DROP TABLE COMUNA;
-- DROP TABLE PROVINCIA;
-- DROP TABLE REGION;